@@ -4,14 +4,14 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000026';
+$LWP::ConsoleLogger::VERSION = '0.000028';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
 use HTTP::Body;
 use HTTP::CookieMonster qw();
 use JSON::MaybeXS qw( decode_json );
-use List::AllUtils qw( apply none );
+use List::AllUtils qw( any apply none );
 use Log::Dispatch qw();
 use Moo;
 use MooX::StrictConstructor;
@@ -21,7 +21,7 @@ use Text::SimpleTable::AutoWidth 0.09 qw();
 use Try::Tiny;
 use Type::Tiny;
 use Types::Common::Numeric qw( PositiveInt );
-use Types::Standard qw( Bool CodeRef InstanceOf );
+use Types::Standard qw( ArrayRef Bool CodeRef InstanceOf );
 use URI::Query qw();
 use URI::QueryParam qw();
 use XML::Simple qw( XMLin );
@@ -86,6 +86,13 @@ has dump_uri => (
     default => 1,
 );
 
+has headers_to_redact => (
+    is      => 'rw',
+    isa     => ArrayRef,
+    lazy    => 1,
+    builder => '_build_headers_to_redact',
+);
+
 has html_restrict => (
     is      => 'rw',
     isa     => InstanceOf ['HTML::Restrict'],
@@ -100,11 +107,20 @@ has logger => (
     handles => { _debug => 'debug' },
     default => sub {
         return Log::Dispatch->new(
-            outputs => [ [ 'Screen', min_level => 'debug', newline => 1, ], ],
+            outputs => [
+                [ 'Screen', min_level => 'debug', newline => 1, utf8 => 1, ],
+            ],
         );
     },
 );
 
+has params_to_redact => (
+    is      => 'rw',
+    isa     => ArrayRef,
+    lazy    => 1,
+    builder => '_build_params_to_redact',
+);
+
 has term_width => (
     is       => 'rw',
     isa      => PositiveInt,
@@ -119,6 +135,20 @@ has text_pre_filter => (
     isa => CodeRef,
 );
 
+sub _build_headers_to_redact {
+    my $self = shift;
+    return $ENV{LWPCL_REDACT_HEADERS}
+        ? [ split m{,}, $ENV{LWPCL_REDACT_HEADERS} ]
+        : [];
+}
+
+sub _build_params_to_redact {
+    my $self = shift;
+    return $ENV{LWPCL_REDACT_PARAMS}
+        ? [ split m{,}, $ENV{LWPCL_REDACT_PARAMS} ]
+        : [];
+}
+
 sub _term_set {
     my $self  = shift;
     my $width = shift;
@@ -179,7 +209,11 @@ sub _log_headers {
 
     foreach my $name ( sort $headers->header_field_names ) {
         next if $name eq 'Cookie' || $name eq 'Set-Cookie';
-        $t->row( $name, $headers->header($name) );
+        my $val = (
+            any { $name eq $_ }
+            @{ $self->headers_to_redact }
+        ) ? '[REDACTED]' : $headers->header($name);
+        $t->row( $name, $val );
     }
 
     $self->_draw($t);
@@ -231,8 +265,13 @@ sub _log_params {
     my $t = Text::SimpleTable::AutoWidth->new();
     $t->captions( [ 'Key', 'Value' ] );
     foreach my $name ( sort keys %params ) {
-        my @values
-            = ref $params{$name} ? @{ $params{$name} } : $params{$name};
+        my @values = (
+            any { $name eq $_ }
+            @{ $self->params_to_redact }
+            )                    ? '[REDACTED]'
+            : ref $params{$name} ? @{ $params{$name} }
+            :                      $params{$name};
+
         $t->row( $name, $_ ) for sort @values;
     }
 
@@ -447,7 +486,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000026
+version 0.000028
 
 =head1 SYNOPSIS
 
@@ -598,6 +637,10 @@ here and discuss them in detail below.
 
 =item * C<< content_pre_filter => sub { ... } >>
 
+=item * C<< headers_to_redact => ['Authentication', 'Foo'] >>
+
+=item * C<< params_to_redact => ['token', 'password'] >>
+
 =item * C<< text_pre_filter => sub { ... } >>
 
 =item * C<< html_restrict => HTML::Restrict->new( ... ) >>
